pub struct ImageComponent {
pub upload_destination_id: String,
pub image_crop_specification: Box<ImageCropSpecification>,
pub alt_text: String,
}Expand description
ImageComponent : A reference to an image, hosted in the A+ Content media library.
Fields
upload_destination_id: StringThis identifier is provided by the Selling Partner API for Uploads.
image_crop_specification: Box<ImageCropSpecification>alt_text: StringThe alternative text for the image.
Implementations
sourceimpl ImageComponent
impl ImageComponent
sourcepub fn new(
upload_destination_id: String,
image_crop_specification: ImageCropSpecification,
alt_text: String
) -> ImageComponent
pub fn new(
upload_destination_id: String,
image_crop_specification: ImageCropSpecification,
alt_text: String
) -> ImageComponent
A reference to an image, hosted in the A+ Content media library.